@@ -206,7 +206,7 @@ https_init(const char *ikey, const char *skey,
         /* Initialize SSL context */
         SSL_library_init();
         SSL_load_error_strings();
-        OpenSSL_add_all_algorithms();
+        OpenSSL_add_ssl_algorithms();
 
         /* XXX - ape openssl s_client -rand for testing on ancient systems */
         if (!RAND_status()) {
@@ -341,7 +341,8 @@ https_open(struct https_request **reqp, const char *host)
                 
                 if (ctx->proxy_auth != NULL) {
                         b64 = _BIO_new_base64();
-                        BIO_puts(b64, ctx->proxy_auth);
+                        BIO_write(b64, ctx->proxy_auth,
+                            strlen(ctx->proxy_auth));
                         (void)BIO_flush(b64);
                         n = BIO_get_mem_data(b64, &p);
 
@@ -461,13 +462,9 @@ https_send(struct https_request *req, const char *method, const char *uri,
         } else {
                 BIO_printf(req->cbio, "Host: %s:%s\r\n", req->host, req->port);
         }
-        /* Add User-Agent header */
-        BIO_printf(req->cbio,
-                   "User-Agent: %s\r\n",
-                   ctx->useragent);
         /* Add signature */
         BIO_puts(req->cbio, "Authorization: Basic ");
-
+        
 	HMAC_CTX_init(&hmac);
 	HMAC_Init(&hmac, ctx->skey, strlen(ctx->skey), EVP_sha1());
 	HMAC_Update(&hmac, (unsigned char *)p, strlen(p));
